NativeClient class

FFI binding functions, see TDLib doc for td_json_client All method names same as c symbols

Constructors

NativeClient({String? dir, String? file})

Properties

hashCode → int
The hash code for this object.
no setterinherited
libtdjson ↔ DynamicLibrary
dynamic lib handler
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
td_create_client_id ↔ td_create_client_id
FFI binding function, see TDLib doc for td_json_client
latefinal
td_execute ↔ td_execute
FFI binding function, see TDLib doc for td_json_client
latefinal
td_json_client_create ↔ td_json_client_create
FFI binding function, see TDLib doc for td_json_client
latefinal
td_json_client_destroy ↔ td_json_client_destroy
FFI binding function, see TDLib doc for td_json_client
latefinal
td_json_client_execute ↔ td_json_client_execute
FFI binding function, see TDLib doc for td_json_client
latefinal
td_json_client_receive ↔ td_json_client_receive
FFI binding function, see TDLib doc for td_json_client
latefinal
td_json_client_send ↔ td_json_client_send
FFI binding function, see TDLib doc for td_json_client
latefinal
td_receive ↔ td_receive
FFI binding function, see TDLib doc for td_json_client
latefinal
td_send ↔ td_send
FFI binding function, see TDLib doc for td_json_client
latefinal
td_set_log_message_callback ↔ td_set_log_message_callback
FFI binding function, see TDLib doc for td_json_client
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

loadLibrary({String? dir, String? file}) → DynamicLibrary