RawService class

The raw client only handles the stream loop for td receive function

Implementers

Constructors

RawService({String? dir, String? file, double timeout = 30, int? newVerbosityLevel, void onStreamError(dynamic)?, void onReceive(String)?})

Properties

dir → String?
final
file → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isRunning → bool
no setter
newVerbosityLevel ↔ int?
Initial new_verbosity_level for td function setLogVerbosityLevel
getter/setter pair
onReceive ↔ void Function(String)?
The event fired after service handling receiving raw string result from td json client (via receive stream loop)
getter/setter pair
onStreamError ↔ void Function(dynamic)?
dart Stream(onError) for receive stream loop
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout ↔ double
Timeout (second) for event loop of receive stream. (td receive), it only works when calling the start fn
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<void>
Start receiving messages from native td json client
stop() → Future<void>
Stop receiving messages from native td json client, use this wisely
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited